from setuptools import setup
version = '0.1.2'
setup(
    author='evergaster',
    name='cord64',
    version=version,
    license='MIT License',
    description='Convert files to Base64 and vice versa.',
    long_description=open('README.md').read(),
    keywords='base64 convert file',
    long_description_content_type='text/markdown',
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    	"Development Status :: 4 - Beta",
    	"Natural Language :: English",
    	"Operating System :: Microsoft :: Windows :: Windows 10",
    	"Programming Language :: Python :: 3",
    	"Programming Language :: Python :: 3.9",
    	"Topic :: Internet"
    ]

)